@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/mac.tcl,v $
-# $Date: 1998/03/25 10:42:49 $
-# $Revision: 1.18.1.9 $
+# $Source: /home/nlfm/Zircon/installer/RCS/mac.tcl,v $
+# $Date: 1998/09/07 12:01:50 $
+# $Revision: 1.18.1.10 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -83,6 +83,9 @@ proc beforeInstall {args} {
 }
 #
 proc whereLib {} { return {[pwd]} }
+#
+proc makeExecutable {file} { }
+
 
 
 
