@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Channel.tcl,v $
-# $Date: 1998/11/13 14:53:01 $
-# $Revision: 1.18.1.178 $
+# $Date: 1998/11/16 14:10:50 $
+# $Revision: 1.18.1.180 $
 #
 #
 package provide zircon 1.18
@@ -525,7 +525,7 @@ for regular expression \"$v\" in -ban for channel [$this name]"
 	-buttons {
 		set cdata(buttons) $val
 		if {[winfo exists $cdata(window).users.menu]} {
-		    $cdata(window).users.menu entryconfigure 0 -label \
+		    $cdata(window).users.menu entryconfigure 1 -label \
 		      [trans [expr {[$this buttons] ? {no buttons} : {buttons}}]]
 		}
 	    }
@@ -1441,8 +1441,10 @@ proc cpriv {chan op spk menu x} {
 }
 #
 proc cpriv1 {chan op spk usr2} {
-    set op1 [$chan isOp $usr2]
-    set spk1 [$chan isSpeaker $usr2]
+    return [cpriv2 $op $spk [$chan isOp $usr2] [$chan isSpeaker $usr2]]
+}
+#
+proc cpriv2 {op spk op1 spk1} {
     if {$op} {
         if {$op1} { return 1}
 	return 2
@@ -1497,28 +1499,21 @@ proc sortIns {chan nk usr w} {
     return last
 }
 #
-proc wsortIns {chan win un usr args} {
+proc wsortIns {chan win un usr} {
     set wnk $win.$usr
     set fn name
     set fn1 cpriv1
-    switch nil $chan {
-	if {[[$usr net] ircIIops]} {
-	    set txt [lindex $args 0]$un
-	} {
-	    set txt $un
-	}
-	set srt 1
-    } default {
-	set txt [$chan osTag $usr $un]
-	set srt [expr {![$chan nosort]}]
-	if {[$chan nocase]} {
-	    set un [string tolower $un]
-	    set fn lname
-	}
-	if {[$chan nopriv]} {
-	    set fn1 nop
-	}
+    set txt [$chan osTag $usr $un]
+    set srt [expr {![$chan nosort]}]
+    if {[$chan nocase]} {
+	set un [string tolower $un]
+	set fn lname
     }
+    if {[$chan nopriv]} {
+	set fn1 nop
+    }
+    set op [$chan isOp $usr]
+    set spk [$chan isSpeaker $usr]
     set top text
     set wd [$win cget -width]
     switch nil [set fr [$usr fobj]] {} default {
@@ -1541,8 +1536,6 @@ proc wsortIns {chan win un usr args} {
     switch {} $wd {} default { $wnk configure -width $wd }
     $wnk configure -menu [makeUserMenu $chan $wnk.menu $usr]
     if {$srt} {
-        set op [$chan isOp $usr]
-	set spk [$chan isSpeaker $usr]
 	set y 1
 	while {![catch {set x [$win window cget 1.$y -window]}]} {
 	    switch {} $x {} default {
@@ -1895,14 +1888,11 @@ proc channel_unpack {this where} {
     foreach prop [array names config] {
 	$this configure -$prop $new($prop)
     }
-#    foreach prop {foreground background} {
-#	switch {} $new($prop) {} default {$this configure -$prop $new($prop)}
-#    }
     unset new
 }
 #
-proc Channel_cleanup {net} {
-    foreach ch [$net channels] { catch {uplevel #0 unset new$ch} }
+proc Channel_cleanup {net where} {
+    foreach ch [$net channels] { safeUnset ${where}$ch }
 }
 #
 proc indexHack {w nk start} {
