@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Net.tcl,v $
-# $Date: 1998/11/13 12:21:45 $
-# $Revision: 1.18.1.160 $
+# $Date: 1998/11/16 14:10:56 $
+# $Revision: 1.18.1.161 $
 #
 package provide zircon 1.18
 #
@@ -916,3 +916,11 @@ proc net_fileProcess {this file usr} {
 	}
     }
 }
+#
+proc net_cleanup {this where} {
+    foreach nm {servers channels messages chats notices friends services} {
+        foreach x [$this $nm] {
+	    safeUnset ${where}$x
+	}
+    }
+}
